#' Constants for 'glmSparseNet' package
#'
#' Log level constants and the logger options.
#'
#' The logging configuration is managed by 'glmSparseNet.options', a function
#' generated by OptionsManager within 'futile.options'.
#'
#' @name glmSparseNet.options
#' @usage glmSparseNet.options(..., simplify = FALSE, update = list())
#'
#' @param update pair list of update to options
#' @param ... TODO
#' @param simplify TODO
#'
#' @return futile.options::OptionsManager object
#'
#' @seealso \code{futile.options}
glmSparseNet.options <- futile.options::OptionsManager(
  'glmSparseNet',
  default = list(
    compression = 'gzip',
    base.dir = tempdir.cache(),
    show.message = TRUE
  )
)

#' change cache.compression for run.cache
#'
#' @param compression see compression parameter in save function
#'
#' @return the new compression
#'
#' @examples
#' glmSparseNet:::cache.compression('bzip2')
cache.compression <- function(compression = NULL) {
  if (!is.null(compression))
    glmSparseNet.options(update = list('compression', compression))
  return(glmSparseNet.options('compression'))
}

#' change base.dir for run.cache
#'
#' @param path to base directory where cache is saved
#'
#' @return the new path
#'
#' @examples
#' glmSparseNet:::base.dir('/tmp/cache')
base.dir <- function(path = NULL) {
  if (!is.null(path))
    glmSparseNet.options(update = list('base.dir', path))
  return(glmSparseNet.options('base.dir'))
}

#' Show messages option in run.cache
#'
#' @param show.message boolean indicating to show messages or not
#'
#' @return the show.message option
#'
#' @examples
#' glmSparseNet:::show.message(FALSE)
show.message <- function(show.message = NULL) {
  if (!is.null(show.message))
    glmSparseNet.options(update = list('show.message', show.message))
  return(glmSparseNet.options('show.message'))
}
